<?php

namespace Bydedi\Http\TemplatePlugin;

use Bydedi\Template\AbstractPlugin;
use Smarty_Internal_Template;
use Symfony\Component\HttpFoundation\RequestStack;
use Symfony\Component\HttpFoundation\Session\Session;

class FlashMessagePlugin extends AbstractPlugin
{
    /**
     * @var RequestStack
     */
    protected $requestStack;

    public function __construct(RequestStack $requestStack)
    {
        $this->requestStack = $requestStack;
    }

    /**
     * @return Session
     */
    protected function getSession()
    {
        return $this->requestStack->getMasterRequest()->getSession();
    }

    public function generate($params, Smarty_Internal_Template $template)
    {
        $flashBag = $this->getSession()->getFlashBag();

        $html = '';

        if ($flashBag->has($params['type'])) {

            $tpl = sprintf('flashes/%s.tpl', $params['type']);

            if ($template->smarty->templateExists($tpl) == false) {
                trigger_error(sprintf('template "%s" does not exist', $tpl), E_USER_WARNING);
                return $html;
            }

            $template->smarty->assign('messages', $flashBag->get($params['type']));
            $html = $template->smarty->fetch($tpl);
        }

        return $html;
    }

    public function register()
    {
        return [
            'function',
            'flash_message',
            array($this, 'generate')
        ];
    }
}
