<?php

namespace Bydedi\Security;

use Bydedi\Security\Driver\DriverInterface;
use Bydedi\Security\Entity\Permission;

/**
 * Class Locker
 * @package Dedi\Security
 *
 * Represente les droits d'accès au ressource pour une requete d'un client
 *
 */
class Locker
{

    /**
     * @var \Bydedi\Security\Entity\Role[] roles du client qui demande la requete
     */
    protected $roles;

    /**
     * @var DriverInterface
     */
    protected $driver;

    /**
     * @param DriverInterface $driver
     */
    public function __construct(DriverInterface $driver)
    {
        $this->driver = $driver;
        $this->roles = $this->driver->getRoles();
    }

    /**
     * @param \Bydedi\Security\Entity\Role[] $roles
     * @param Permission $permission
     * @return bool
     */
    public function can($roles, Permission $permission)
    {
        if (is_array($roles) == false) {
            $roles = array($roles);
        }

        foreach ($this->roles as $role) {
            if (in_array($role->getCode(), $roles) == true && $role->havePermission($permission) == true) {
                return true;
            }
        }

        return false;
    }

    /**
     * @param string $permissionCode
     * @return Permission|false
     */
    public function findPermissionByCode($permissionCode)
    {
        return $this->driver->findPermissionByCode($permissionCode);
    }

    /**
     * @param $roleName
     * @return \Bydedi\Security\Entity\Role|false
     */
    public function findRoleByCode($roleName)
    {
        return $this->driver->findRoleByCode($roleName);
    }
}
